@@ -1,5 +1,38 @@
 // kdelibs4.js of Serbian KDE translation
 
+// ------------------------------
+// Simplistic Cyrillic to Latin conversion:
+// - does not handle digraphs properly, e.g. ЉУБЉАНА→LjUBLjANA
+// - does not handle accented letters in NFC
+
+var _c2l_map_ = {
+    "а":"a", "б":"b", "в":"v", "г":"g", "д":"d", "ђ":"đ",
+    "е":"e", "ж":"ž", "з":"z", "и":"i", "ј":"j", "к":"k",
+    "л":"l", "љ":"lj","м":"m", "н":"n", "њ":"nj","о":"o",
+    "п":"p", "р":"r", "с":"s", "т":"t", "ћ":"ć", "у":"u",
+    "ф":"f", "х":"h", "ц":"c", "ч":"č", "џ":"dž","ш":"š",
+    "А":"A", "Б":"B", "В":"V", "Г":"G", "Д":"D", "Ђ":"Đ",
+    "Е":"E", "Ж":"Ž", "З":"Z", "И":"I", "Ј":"J", "К":"K",
+    "Л":"L", "Љ":"Lj","М":"M", "Н":"N", "Њ":"Nj","О":"O",
+    "П":"P", "Р":"R", "С":"S", "Т":"T", "Ћ":"Ć", "У":"U",
+    "Ф":"F", "Х":"H", "Ц":"C", "Ч":"Č", "Џ":"Dž","Ш":"Š",
+};
+
+function c2l (str)
+{
+    var strl = "";
+    for (var i = 0; i < str.length; i++) {
+        var c = str.charAt(i);
+        var cl = _c2l_map_[c];
+        if (cl) {
+            strl += cl;
+        } else {
+            strl += c;
+        }
+    }
+    return strl;
+}
+
 // ------------------------------
 // Property getter object contains the following data attributes:
 // - callname: the name of the getter call as exposed to PO files
@@ -84,10 +117,12 @@ function setcalls_prop (pgetr)
 {
     // Default call.
     Ts.setcall(pgetr.callname, pgetr.getprop, pgetr);
+    Ts.setcall(c2l(pgetr.callname), pgetr.getprop, pgetr);
     // "Open with $[callname %1]"
 
     // Form call.
     Ts.setcall(pgetr.callname + "/ф", pgetr.getform, pgetr);
+    Ts.setcall(c2l(pgetr.callname + "/ф"), pgetr.getform, pgetr);
     // "Open with $[callname/ф %1]"
 
     // The calls which capitalize the first letter of the value,
@@ -96,8 +131,10 @@ function setcalls_prop (pgetr)
     callname_uc = Ts.toUpperFirst(pgetr.callname);
     if (callname_uc != pgetr.callname) {
         Ts.setcall(callname_uc, pgetr.getprop_uc, pgetr);
+        Ts.setcall(c2l(callname_uc), pgetr.getprop_uc, pgetr);
         // "$[Callname %1] starting..."
         Ts.setcall(callname_uc + "/ф", pgetr.getform_uc, pgetr);
+        Ts.setcall(c2l(callname_uc + "/ф"), pgetr.getform_uc, pgetr);
         // "$[Callname/ф %1] starting..."
     }
 
@@ -159,6 +196,13 @@ function hasprop (phrase, pkey)
     return true;
 }
 
+// Set PO calls for given generic function.
+function setcalls (callname, callfunc)
+{
+    Ts.setcall(callname, callfunc);
+    Ts.setcall(c2l(callname), callfunc);
+}
+
 // ------------------------------
 // Predefined property getters.
 
@@ -295,7 +339,7 @@ function setprops_msgstrf (/*...*/)
     setprops(Ts.msgstrf(), arguments);
     throw Ts.fallback();
 }
-Ts.setcall("својства", setprops_msgstrf);
+setcalls("својства", setprops_msgstrf);
 // "$[callname prop1 value1 prop2 value2 ...]"
 
 // Manually set properties of the phrase given by the finalized msgstr
@@ -308,7 +352,7 @@ function setprops_msgstrf_e (/*...*/)
     setprops(Ts.msgstrf(), arguments);
     return "";
 }
-Ts.setcall("својства/п", setprops_msgstrf_e);
+setcalls("својства/п", setprops_msgstrf_e);
 // "$[callname prop1 value1 prop2 value2 ...]"
 
 // ------------------------------
@@ -326,7 +370,7 @@ function plural3 (n, form0, form1, form2)
     else
         return form2;
 }
-Ts.setcall("множ", plural3);
+setcalls("множ", plural3);
 // "...and %2 $[callname ^2 file fila files]"
 
 // ------------------------------
@@ -349,7 +393,7 @@ function select_by_gender (phrase, form_m, form_f, form_n)
         throw Ts.fallback();
     }
 }
-Ts.setcall("по-роду", select_by_gender);
+setcalls("по-роду", select_by_gender);
 // "Delete $[callname %1 this thisa thiso] %1?"
 
 // ------------------------------
@@ -370,7 +414,7 @@ function select_by_number_gender (phrase,
         return select_by_gender(phrase, form_m, form_f, form_n);
     }
 }
-Ts.setcall("по-роду-броју", select_by_number_gender);
+setcalls("по-роду-броју", select_by_number_gender);
 // "Delete $[callname %1 this thisa thiso thees theesa theeso] %1?"
 
 // ------------------------------
@@ -380,7 +424,7 @@ function select_by_case_gender (gcase, gphrase, phrase) // plurals
     var gender = getprop(gphrase, "_род");
     return getprop(phrase, gcase + "-" + gender);
 }
-Ts.setcall("по-падежу-роду", select_by_case_gender);
+setcalls("по-падежу-роду", select_by_case_gender);
 // "Delete $[callname case %2 %1] [case %2]?"
 
 // ------------------------------
@@ -463,7 +507,7 @@ function apply_to_word (/* phrase, callname, ...args before word... */)
 
     return str;
 }
-Ts.setcall("на-реч", apply_to_word);
+setcalls("на-реч", apply_to_word);
 // "Repeat until $[callname casecall %1], and on this date..."
 
 // ------------------------------
@@ -488,7 +532,7 @@ function decline_person_name (gcase, fullname)
 {
     return decline_person_name_base(gcase, fullname, false);
 }
-Ts.setcall("именски", decline_person_name);
+setcalls("именски", decline_person_name);
 // "You have invited $[callname case %1] to the party."
 
 // Decline person's name, return as-is if not possible.
@@ -496,7 +540,7 @@ function decline_person_name_nf (gcase, fullname)
 {
     return decline_person_name_base(gcase, fullname, true);
 }
-Ts.setcall("именски/ф", decline_person_name_nf);
+setcalls("именски/ф", decline_person_name_nf);
 // "You have invited $[callname case %1] to the party."
 
 // ------------------------------
@@ -525,7 +569,7 @@ function match_style_to_font (compstyle, gcase)
     }
     return final.substr(1); // to remove initial space
 }
-Ts.setcall("стил-према-фонту", match_style_to_font);
+setcalls("стил-према-фонту", match_style_to_font);
 
 // ------------------------------
 // Pick a phrase depending on a dynamic context field.
@@ -562,7 +606,7 @@ function select_by_context (/* ctxt_key,
 
     return phrase;
 }
-Ts.setcall("по-контексту", select_by_context);
+setcalls("по-контексту", select_by_context);
 
 // ------------------------------
 // Load property maps.
